@@ -20,7 +20,9 @@ def connect_hub():
 def sign_up_hub(email) -> Union[str, None]:
     hub = connect_hub()
     password = id.id_secret()  # generate new password
-    user = hub.auth.sign_up(email=email, password=password)
+    user = hub.auth.sign_up(
+        email=email, password=password, redirect_to="https://lamin.ai/signup"
+    )
     # if user already exists a fake user object without identity is returned
     if user.identities:
         # if user had called sign-up before, but not confirmed their email
@@ -61,6 +63,7 @@ def sign_in_hub(email, password, handle=None):
     if len(data.data) > 0:  # user is completely registered
         user_id = data.data[0]["lnid"]
         user_handle = data.data[0]["handle"]
+        user_name = data.data[0]["name"]
         if handle is not None and handle != user_handle:
             logger.warning(
                 f"Passed handle {handle} does not match your account handle"
@@ -70,7 +73,7 @@ def sign_in_hub(email, password, handle=None):
         logger.error("Complete signup on your account page.")
         return "complete-signup"
     hub.auth.sign_out()
-    return user_id, user_handle
+    return user_id, user_handle, user_name
 
 
 def create_instance(instance_name):
