@@ -1,5 +1,6 @@
 from dataclasses import dataclass
 from pathlib import Path
+from sqlite3 import Connection as SQLite3Connection
 from typing import Optional, Union
 
 import sqlmodel as sqm
@@ -7,6 +8,19 @@ from appdirs import AppDirs
 from cloudpathlib import CloudPath, GSClient, S3Client
 from cloudpathlib.exceptions import OverwriteNewerLocalError
 from lamin_logger import logger
+from sqlalchemy import event
+from sqlalchemy.engine import Engine
+
+
+# https://stackoverflow.com/questions/2614984/sqlite-sqlalchemy-how-to-enforce-foreign-keys
+# foreign key constraints for sqlite3
+@event.listens_for(Engine, "connect")
+def _set_sqlite_pragma(dbapi_connection, connection_record):
+    if isinstance(dbapi_connection, SQLite3Connection):
+        cursor = dbapi_connection.cursor()
+        cursor.execute("PRAGMA foreign_keys=ON;")
+        cursor.close()
+
 
 DIRS = AppDirs("lamindb", "laminlabs")
 
@@ -21,9 +35,9 @@ class Storage:
 
         Returns "s3" or "gs" or "local".
         """
-        if str(self.settings.storage_dir).startswith("s3://"):
+        if str(self.settings.storage_root).startswith("s3://"):
             storage_type = "s3"
-        elif str(self.settings.storage_dir).startswith("gs://"):
+        elif str(self.settings.storage_root).startswith("gs://"):
             storage_type = "gs"
         else:
             storage_type = "local"
@@ -43,9 +57,9 @@ class Storage:
                     "Currently, only AWS S3 and Google cloud are supported for cloud"
                     " storage."
                 )
-            return client.CloudPath(self.settings.storage_dir / filekey)
+            return client.CloudPath(self.settings.storage_root / filekey)
         else:
-            return self.settings.storage_dir / filekey
+            return self.settings.storage_root / filekey
 
     def cloud_to_local(self, filepath: Union[Path, CloudPath]) -> Path:
         """Local (cache) filepath from filepath."""
@@ -85,7 +99,7 @@ class Storage:
 
 
 class instance_description:
-    storage_dir = """Storage root. Either local dir, ``s3://bucket_name`` or ``gs://bucket_name``."""  # noqa
+    storage_root = """Storage root. Either local dir, ``s3://bucket_name`` or ``gs://bucket_name``."""  # noqa
     storage_region = """Cloud storage region for s3 and Google Cloud."""
     _dbconfig = """Either "sqlite" or "instance_name, postgres_url"."""
     name = """Instance name."""
@@ -100,7 +114,7 @@ def instance_from_storage(storage):
 class InstanceSettings:
     """Instance settings written during setup."""
 
-    storage_dir: Union[CloudPath, Path] = None  # None is just for init, can't be None
+    storage_root: Union[CloudPath, Path] = None  # None is just for init, can't be None
     """Storage root. Either local dir, ``s3://bucket_name`` or ``gs://bucket_name``."""
     storage_region: Optional[str] = None
     """Cloud storage region for s3 and Google Cloud."""
@@ -111,8 +125,8 @@ class InstanceSettings:
 
     @property
     def cloud_storage(self) -> bool:
-        """`True` if `storage_dir` is in cloud, `False` otherwise."""
-        return isinstance(self.storage_dir, CloudPath)
+        """`True` if `storage_root` is in cloud, `False` otherwise."""
+        return isinstance(self.storage_root, CloudPath)
 
     @property
     def cache_dir(
@@ -132,7 +146,7 @@ class InstanceSettings:
 
         Is a CloudPath if on S3, otherwise a Path.
         """
-        filename = instance_from_storage(self.storage_dir)  # type: ignore
+        filename = instance_from_storage(self.storage_root)  # type: ignore
         return self.storage.key_to_filepath(f"{filename}.lndb")
 
     @property
@@ -145,15 +159,15 @@ class InstanceSettings:
         if self.cloud_storage:
             sqlite_file = self._sqlite_file
             cache_file = self.storage.cloud_to_local_no_update(sqlite_file)
-            sqlite_file.upload_from(cache_file)  # type: ignore
+            sqlite_file.upload_from(cache_file, force_overwrite_to_cloud=True)  # type: ignore  # noqa
 
     @property
     def name(self) -> Union[str, None]:
         """Name of LaminDB instance, which corresponds to exactly one database."""
-        if self.storage_dir is None:  # not yet initialized
+        if self.storage_root is None:  # not yet initialized
             return None
         if self._dbconfig == "sqlite":
-            return instance_from_storage(self.storage_dir)
+            return instance_from_storage(self.storage_root)
         else:
             return self._dbconfig.split("/")[-1]
 
