@@ -58,20 +58,20 @@ def load_user_settings(user_settings_file: Path):
     return settings
 
 
-def setup_storage_dir(storage: Union[str, Path, CloudPath]) -> Union[Path, CloudPath]:
+def setup_storage_root(storage: Union[str, Path, CloudPath]) -> Union[Path, CloudPath]:
     if str(storage).startswith(("s3://", "gs://")):
-        storage_dir = CloudPath(storage)
+        storage_root = CloudPath(storage)
     elif str(storage) == "null":
         return None
     else:
-        storage_dir = Path(storage).absolute()
-        storage_dir.mkdir(parents=True, exist_ok=True)
-    return storage_dir
+        storage_root = Path(storage).absolute()
+        storage_root.mkdir(parents=True, exist_ok=True)
+    return storage_root
 
 
 def setup_instance_from_store(store: InstanceSettingsStore) -> InstanceSettings:
     settings = InstanceSettings()
-    settings.storage_dir = setup_storage_dir(store.storage_dir)
+    settings.storage_root = setup_storage_root(store.storage_root)
     settings._dbconfig = store.dbconfig
     settings.schema_modules = (
         store.schema_modules if store.schema_modules != "null" else None
@@ -86,4 +86,5 @@ def setup_user_from_store(store: UserSettingsStore) -> UserSettings:
     settings.password = store.password if store.password != "null" else None
     settings.id = store.id if store.id != "null" else None
     settings.handle = store.handle if store.handle != "null" else None
+    settings.name = store.name if store.name != "null" else None
     return settings
