@@ -20,7 +20,7 @@ current_user_settings_file = settings_dir / "current_user.env"
 
 
 class InstanceSettingsStore(BaseSettings):
-    storage_dir: str
+    storage_root: str
     storage_region: str
     dbconfig: str
     schema_modules: str
@@ -34,6 +34,7 @@ class UserSettingsStore(BaseSettings):
     password: str
     id: str
     handle: str
+    name: str
 
     class Config:
         env_file = ".env"
