@@ -5,7 +5,7 @@ from cloudpathlib import CloudPath
 from lamin_logger import logger
 from sqlalchemy import text
 
-from ._db import insert_if_not_exists
+from ._db import insert_if_not_exists, upsert
 from ._docs import doc_args
 from ._migrate import check_migrate
 from ._settings_instance import InstanceSettings
@@ -14,7 +14,7 @@ from ._settings_load import (
     load_instance_settings,
     load_or_create_instance_settings,
     load_or_create_user_settings,
-    setup_storage_dir,
+    setup_storage_root,
 )
 from ._settings_save import save_instance_settings
 from ._settings_store import settings_dir
@@ -23,9 +23,11 @@ from ._setup_storage import get_storage_region
 
 
 def update_db(isettings, usettings):
-    insert_if_not_exists.user(usettings.email, usettings.id, usettings.handle)
+    # we should also think about updating the user name here at some point!
+    # (passing user.name from cloud to the upsert as is done in setup_user.py)
+    upsert.user(usettings.email, usettings.id, usettings.handle, usettings.name)
 
-    insert_if_not_exists.storage(isettings.storage_dir, isettings.storage_region)
+    insert_if_not_exists.storage(isettings.storage_root, isettings.storage_region)
 
 
 def setup_instance_db():
@@ -37,12 +39,12 @@ def setup_instance_db():
     """
     isettings = load_or_create_instance_settings()
     usettings = load_or_create_user_settings()
-    if isettings.storage_dir is None:
+    if isettings.storage_root is None:
         logger.warning("Instance is not configured. Call `lndb init` or `lndb load`.")
         return None
 
-    if isettings._sqlite_file.exists():
-        logger.info(f"Using instance: {isettings._sqlite_file}")
+    if instance_exists(isettings):
+        logger.info(f"Loading instance: {isettings.name}")
         check_migrate(usettings=usettings, isettings=isettings)
     else:
         if isettings.cloud_storage and isettings._sqlite_file_local.exists():
@@ -53,30 +55,32 @@ def setup_instance_db():
                 " location."
             )
             return None
-        if isettings._dbconfig != "sqlite":
-            if schema_exists(isettings):
-                return None
         setup_schema(isettings, usettings)
 
     update_db(isettings, usettings)
 
 
-def schema_exists(isettings: InstanceSettings):
-    with isettings.db_engine().connect() as conn:
-        results = conn.execute(
-            text(
-                """
-            SELECT EXISTS (
-                SELECT FROM
-                    information_schema.tables
-                WHERE
-                    table_schema LIKE 'public' AND
-                    table_name = 'user'
-            );
-        """
-            )
-        ).first()
-        return results[0]
+def instance_exists(isettings: InstanceSettings):
+    if isettings._sqlite_file.exists():
+        return True
+    elif isettings._dbconfig != "sqlite":
+        with isettings.db_engine().connect() as conn:
+            results = conn.execute(
+                text(
+                    """
+                SELECT EXISTS (
+                    SELECT FROM
+                        information_schema.tables
+                    WHERE
+                        table_schema LIKE 'public' AND
+                        table_name = 'user'
+                );
+            """
+                )
+            ).first()
+            return results[0]
+    else:
+        return False
 
 
 def load(instance_name: str):
@@ -98,7 +102,7 @@ def load(instance_name: str):
 
 
 @doc_args(
-    description.storage_dir,
+    description.storage_root,
     description._dbconfig,
     description.schema_modules,
 )
@@ -124,8 +128,10 @@ def init(
     instance_settings = InstanceSettings()
 
     # setup storage
-    instance_settings.storage_dir = setup_storage_dir(storage)
-    instance_settings.storage_region = get_storage_region(instance_settings.storage_dir)
+    instance_settings.storage_root = setup_storage_root(storage)
+    instance_settings.storage_region = get_storage_region(
+        instance_settings.storage_root
+    )
 
     # setup _config
     instance_settings._dbconfig = dbconfig
