@@ -10,6 +10,7 @@ from ._settings_user import UserSettings
 known_schema_names = [
     "bionty",
     "wetlab",
+    "drylab",
     "bfx",
     "retro",
     "swarm",
@@ -33,12 +34,18 @@ def setup_schema(isettings: InstanceSettings, usettings: UserSettings):
     msg = "Loading schema modules: "
     for schema_name in ["core"] + schema_names:
         schema_module = importlib.import_module(get_schema_module_name(schema_name))
-        msg += f"{schema_name}=={schema_module.__version__}, "
-    logger.info(f"{msg[:-2]}.")  # exclude the last comma
+        msg += f"{schema_name}=={schema_module.__version__} "
+    logger.info(f"{msg}")
 
     SQLModel.metadata.create_all(isettings.db_engine())
 
-    insert.user(email=usettings.email, user_id=usettings.id, handle=usettings.handle)
+    # we could try to also retrieve the user name here at some point
+    insert.user(
+        email=usettings.email,
+        user_id=usettings.id,
+        handle=usettings.handle,
+        name=usettings.name,
+    )
 
     for schema_name in ["core"] + schema_names:
         schema_module = importlib.import_module(get_schema_module_name(schema_name))
